AndroidAppAsset

Struct AndroidAppAsset 

pub struct AndroidAppAsset {
    pub certificate: Option<CertificateInfo>,
    pub package_name: Option<String>,
}
Describes an android app asset.

This type is not used in any activity, and only used as part of another schema.

Fields

certificate: Option<CertificateInfo>

Because there is no global enforcement of package name uniqueness, we also require a signing certificate, which in combination with the package name uniquely identifies an app. Some apps’ signing keys are rotated, so they may be signed by different keys over time. We treat these as distinct assets, since we use (package name, cert) as the unique ID. This should not normally pose any problems as both versions of the app will make the same or similar statements. Other assets making statements about the app will have to be updated when a key is rotated, however. (Note that the syntaxes for publishing and querying for statements contain syntactic sugar to easily let you specify apps that are known by multiple certificates.) REQUIRED

package_name: Option<String>

Android App assets are naturally identified by their Java package name. For example, the Google Maps app uses the package name com.google.android.apps.maps. REQUIRED