pub struct CheckResponse {
pub debug_string: Option<String>,
pub error_code: Option<Vec<String>>,
pub linked: Option<bool>,
pub max_age: Option<Duration>,
pub relation_extensions: Option<Vec<HashMap<String, Value>>>,
}Expand description
Response message for the CheckAssetLinks call.
Activities
This type is used in activities, which are methods you may call on this type or where this type is involved in. The list links the activity name, along with information about where it is used (one of request and response).
- check assetlinks (response)
Fields
debug_string: Option<String>Human-readable message containing information intended to help end users understand, reproduce and debug the result. The message will be in English and we are currently not planning to offer any translations. Please note that no guarantees are made about the contents or format of this string. Any aspect of it may be subject to change without notice. You should not attempt to programmatically parse this data. For programmatic access, use the error_code field below.
error_code: Option<Vec<String>>Error codes that describe the result of the Check operation. NOTE: Error codes may be populated even when linked is true. The error codes do not necessarily imply that the request failed, but rather, specify any errors encountered in the statements file(s) which may or may not impact whether the server determines the requested source and target to be linked.
linked: Option<bool>Set to true if the assets specified in the request are linked by the relation specified in the request.
max_age: Option<Duration>From serving time, how much longer the response should be considered valid barring further updates. REQUIRED
relation_extensions: Option<Vec<HashMap<String, Value>>>Statements may specify relation level extensions/payloads to express more details when declaring permissions to grant from the source asset to the target asset. When requested, the API will return relation_extensions specified in any and all statements linking the requested source and target assets by the relation specified in the request.